@@ -51,7 +51,7 @@ class TestCore(unittest.TestCase):
         rs = Rows(self.t1)
         self.assertEqual(rs.size(), len(self.t1))
 
-        rs1 = rs.islice(3, 6)
+        rs1 = rs[3:6]
         self.assertEqual(rs1.size(), 3)
 
     def test_wierd(self):
@@ -326,7 +326,7 @@ class TestCore(unittest.TestCase):
     def test_by(self):
         def sum_by_col1(rs):
             tot = sum(rs['col2'])
-            return rs.update(col2=tot).islice(1)
+            return rs.update(col2=tot)[:1]
 
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
@@ -410,9 +410,13 @@ class TestCore(unittest.TestCase):
         conn['t1'] = self.t1
         conn['t2'] = self.t2
 
-        self.assertEqual(len(conn['t1'].islice(3).list()), 3)
-        self.assertEqual(len(conn['t1'].islice(3, None).list()), 4)
-        self.assertEqual(len(conn['t1'].islice(0, None, 3).list()), 3)
+        self.assertEqual(len(conn['t1']._islice(3).list()), 3)
+        self.assertEqual(len(conn['t1']._islice(3, None).list()), 4)
+        self.assertEqual(len(conn['t1']._islice(0, None, 3).list()), 3)
+
+        self.assertEqual(len(conn['t1'][:3].list()), 3)
+        self.assertEqual(len(conn['t1'][3:].list()), 4)
+        self.assertEqual(len(conn['t1'][0::3].list()), 3)
 
         xs = conn['t1']._iter()
         ys = conn['t2']._iter()
@@ -425,6 +429,12 @@ class TestCore(unittest.TestCase):
 
         self.assertEqual(n3, n1 * n2)
 
+        xs = conn['t1'][0:5].filter(lambda r: r['col2'] > 3)
+        ys = conn['t1'][0:8].filter(lambda r: r['col2'] > 3)
+
+        self.assertEqual(len(xs.list()), 3)
+        self.assertEqual(len(ys.list()), 4)
+
     def test_takewhile(self):
         conn = Conn(self.dbfile)
         conn['t1'] = self.t1
